<?php

namespace Location\PushNotification\Policies;

use Litepie\User\Contracts\UserPolicy;
use Location\PushNotification\Models\PushNotification;

class PushNotificationPolicy
{

    /**
     * Determine if the given user can view the push_notification.
     *
     * @param UserPolicy $user
     * @param PushNotification $push_notification
     *
     * @return bool
     */
    public function view(UserPolicy $user, PushNotification $push_notification)
    {
        if ($user->canDo('push_notification.push_notification.view') && $user->isAdmin()) {
            return true;
        }

        return $push_notification->user_id == user_id() && $push_notification->user_type == user_type();
    }

    /**
     * Determine if the given user can create a push_notification.
     *
     * @param UserPolicy $user
     * @param PushNotification $push_notification
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('push_notification.push_notification.create');
    }

    /**
     * Determine if the given user can update the given push_notification.
     *
     * @param UserPolicy $user
     * @param PushNotification $push_notification
     *
     * @return bool
     */
    public function update(UserPolicy $user, PushNotification $push_notification)
    {
        if ($user->canDo('push_notification.push_notification.edit') && $user->isAdmin()) {
            return true;
        }

        return $push_notification->user_id == user_id() && $push_notification->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given push_notification.
     *
     * @param UserPolicy $user
     * @param PushNotification $push_notification
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, PushNotification $push_notification)
    {
        return $push_notification->user_id == user_id() && $push_notification->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given push_notification.
     *
     * @param UserPolicy $user
     * @param PushNotification $push_notification
     *
     * @return bool
     */
    public function verify(UserPolicy $user, PushNotification $push_notification)
    {
        if ($user->canDo('push_notification.push_notification.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given push_notification.
     *
     * @param UserPolicy $user
     * @param PushNotification $push_notification
     *
     * @return bool
     */
    public function approve(UserPolicy $user, PushNotification $push_notification)
    {
        if ($user->canDo('push_notification.push_notification.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
